@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class ActivityDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ActivityId: 活动id
 注意：此字段可能返回 null，表示取不到有效值。
         :type ActivityId: int
@@ -84,7 +84,7 @@ class ActivityDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -94,7 +94,7 @@ class ActivityJoinDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ActivityId: 活动id
 注意：此字段可能返回 null，表示取不到有效值。
         :type ActivityId: int
@@ -184,7 +184,7 @@ class ActivityJoinDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -194,7 +194,7 @@ class ChannelCodeInnerDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Id: 渠道活码id
         :type Id: int
         :param Type: 欢迎语类型，0：普通欢迎语、1:渠道欢迎语
@@ -273,7 +273,7 @@ class ChannelCodeInnerDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -283,7 +283,7 @@ class ChatArchivingDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param MsgId: 消息id
         :type MsgId: str
         :param Action: 动作名称，switch表示切换企微账号，send表示企微普通消息
@@ -339,7 +339,7 @@ https://open.work.weixin.qq.com/api/doc/90000/90135/91774
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -349,7 +349,7 @@ class ChatArchivingMsgTypeVideo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PlayLength: 视频时长，单位秒
 注意：此字段可能返回 null，表示取不到有效值。
         :type PlayLength: int
@@ -373,7 +373,83 @@ class ChatArchivingMsgTypeVideo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ClueInfoDetail(AbstractModel):
+    """线索信息详情
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClueId: 线索id，线索唯一识别编码
+        :type ClueId: str
+        :param DealerId: 接待客户经销商顾问所属组织id,多个组织使用逗号分割
+        :type DealerId: str
+        :param EnquireTime: 线索获取时间，用户添加企业微信时间，单位是秒
+        :type EnquireTime: int
+        :param UnionId: 客户在微信生态中唯一识别码
+        :type UnionId: str
+        :param Name: 微信昵称
+        :type Name: str
+        :param Phone: 联系方式
+        :type Phone: str
+        :param SeriesCode: 车系编号
+        :type SeriesCode: str
+        :param ModelCode: 车型编号
+        :type ModelCode: str
+        :param ProvinceCode: 省份编号
+        :type ProvinceCode: str
+        :param CityCode: 城市编号
+        :type CityCode: str
+        :param SalesName: 顾问名称
+        :type SalesName: str
+        :param SalesPhone: 顾问电话
+        :type SalesPhone: str
+        :param Remark: 备注
+        :type Remark: str
+        :param TagList: 标签
+        :type TagList: list of str
+        """
+        self.ClueId = None
+        self.DealerId = None
+        self.EnquireTime = None
+        self.UnionId = None
+        self.Name = None
+        self.Phone = None
+        self.SeriesCode = None
+        self.ModelCode = None
+        self.ProvinceCode = None
+        self.CityCode = None
+        self.SalesName = None
+        self.SalesPhone = None
+        self.Remark = None
+        self.TagList = None
+
+
+    def _deserialize(self, params):
+        self.ClueId = params.get("ClueId")
+        self.DealerId = params.get("DealerId")
+        self.EnquireTime = params.get("EnquireTime")
+        self.UnionId = params.get("UnionId")
+        self.Name = params.get("Name")
+        self.Phone = params.get("Phone")
+        self.SeriesCode = params.get("SeriesCode")
+        self.ModelCode = params.get("ModelCode")
+        self.ProvinceCode = params.get("ProvinceCode")
+        self.CityCode = params.get("CityCode")
+        self.SalesName = params.get("SalesName")
+        self.SalesPhone = params.get("SalesPhone")
+        self.Remark = params.get("Remark")
+        self.TagList = params.get("TagList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -383,7 +459,7 @@ class CreateChannelCodeRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Type: 欢迎语类型:0普通欢迎语,1渠道欢迎语
         :type Type: int
         :param UseUserId: 使用成员用户id集
@@ -446,7 +522,7 @@ class CreateChannelCodeRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -456,7 +532,7 @@ class CreateChannelCodeResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -465,13 +541,6 @@ class CreateChannelCodeResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateCorpTagRequest(AbstractModel):
@@ -480,7 +549,7 @@ class CreateCorpTagRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GroupName: 标签组名称，最长为15个字符
         :type GroupName: str
         :param Tags: 标签信息数组
@@ -507,7 +576,7 @@ class CreateCorpTagRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -517,7 +586,7 @@ class CreateCorpTagResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TagGroup: 标签组信息
         :type TagGroup: :class:`tencentcloud.wav.v20210129.models.TagGroup`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -532,13 +601,6 @@ class CreateCorpTagResponse(AbstractModel):
             self.TagGroup = TagGroup()
             self.TagGroup._deserialize(params.get("TagGroup"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ExternalContact(AbstractModel):
@@ -547,7 +609,7 @@ class ExternalContact(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExternalUserId: 外部联系人的userId
         :type ExternalUserId: str
         :param Gender: 外部联系人性别 0-未知 1-男性 2-女性
@@ -583,7 +645,7 @@ class ExternalContact(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -593,7 +655,7 @@ class ExternalContactSimpleInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExternalUserId: 外部联系人的userId
         :type ExternalUserId: str
         :param UserId: 添加了此外部联系人的企业成员userId
@@ -601,22 +663,26 @@ class ExternalContactSimpleInfo(AbstractModel):
         :param SalesName: 添加了此外部联系人的企业成员的姓名
 注意：此字段可能返回 null，表示取不到有效值。
         :type SalesName: str
+        :param DepartmentIdList: 添加了此外部联系人的企业成员的归属部门id列表
+        :type DepartmentIdList: list of int
         """
         self.ExternalUserId = None
         self.UserId = None
         self.SalesName = None
+        self.DepartmentIdList = None
 
 
     def _deserialize(self, params):
         self.ExternalUserId = params.get("ExternalUserId")
         self.UserId = params.get("UserId")
         self.SalesName = params.get("SalesName")
+        self.DepartmentIdList = params.get("DepartmentIdList")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -626,7 +692,7 @@ class ExternalContactTag(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GroupName: 该成员添加此外部联系人所打标签的分组名称（标签功能需要企业微信升级到2.7.5及以上版本）
 注意：此字段可能返回 null，表示取不到有效值。
         :type GroupName: str
@@ -656,7 +722,36 @@ class ExternalContactTag(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ExternalUserMappingInfo(AbstractModel):
+    """外部联系人映射信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param CorpExternalUserId: 企业主体对应的外部联系人userId
+        :type CorpExternalUserId: str
+        :param ExternalUserId: 乐销车应用主体对应的外部联系人, 当不存在好友关系时，该字段值为空
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExternalUserId: str
+        """
+        self.CorpExternalUserId = None
+        self.ExternalUserId = None
+
+
+    def _deserialize(self, params):
+        self.CorpExternalUserId = params.get("CorpExternalUserId")
+        self.ExternalUserId = params.get("ExternalUserId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -666,7 +761,7 @@ class FollowUser(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 添加了此外部联系人的企业成员userid
         :type UserId: str
         :param Remark: 该成员对此外部联系人的备注
@@ -712,7 +807,62 @@ class FollowUser(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class LicenseInfo(AbstractModel):
+    """license相关信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param License: license编号
+        :type License: str
+        :param LicenseEdition: license版本；1-基础版，2-标准版，3-增值版
+        :type LicenseEdition: int
+        :param ResourceStartTime: 生效开始时间, 格式yyyy-MM-dd HH:mm:ss
+        :type ResourceStartTime: str
+        :param ResourceEndTime: 生效结束时间, 格式yyyy-MM-dd HH:mm:ss
+        :type ResourceEndTime: str
+        :param IsolationDeadline: 隔离截止时间, 格式yyyy-MM-dd HH:mm:ss
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsolationDeadline: str
+        :param DestroyTime: 资源计划销毁时间, 格式yyyy-MM-dd HH:mm:ss
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DestroyTime: str
+        :param Status: 资源状态，1.正常，2.隔离，3.销毁
+        :type Status: int
+        :param Extra: 扩展信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Extra: str
+        """
+        self.License = None
+        self.LicenseEdition = None
+        self.ResourceStartTime = None
+        self.ResourceEndTime = None
+        self.IsolationDeadline = None
+        self.DestroyTime = None
+        self.Status = None
+        self.Extra = None
+
+
+    def _deserialize(self, params):
+        self.License = params.get("License")
+        self.LicenseEdition = params.get("LicenseEdition")
+        self.ResourceStartTime = params.get("ResourceStartTime")
+        self.ResourceEndTime = params.get("ResourceEndTime")
+        self.IsolationDeadline = params.get("IsolationDeadline")
+        self.DestroyTime = params.get("DestroyTime")
+        self.Status = params.get("Status")
+        self.Extra = params.get("Extra")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -722,7 +872,7 @@ class LiveCodeDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LiveCodeId: 活码id
         :type LiveCodeId: int
         :param LiveCodeName: 活码名称
@@ -775,7 +925,7 @@ class LiveCodeDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -785,7 +935,7 @@ class MiniAppCodeInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Id: 主键id
         :type Id: int
         :param MiniAppName: 小程序名称
@@ -823,7 +973,7 @@ class MiniAppCodeInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -833,7 +983,7 @@ class QueryActivityJoinListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ActivityId: 活动id
         :type ActivityId: int
         :param Cursor: 分页游标，对应结果返回的NextCursor,首次请求保持为空
@@ -855,7 +1005,7 @@ class QueryActivityJoinListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -865,7 +1015,7 @@ class QueryActivityJoinListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextCursor: 分页游标
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextCursor: str
@@ -889,13 +1039,6 @@ class QueryActivityJoinListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryActivityListRequest(AbstractModel):
@@ -904,7 +1047,7 @@ class QueryActivityListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cursor: 分页游标，对应结果返回的NextCursor,首次请求保持为空
         :type Cursor: str
         :param Limit: 单页数据限制
@@ -922,7 +1065,7 @@ class QueryActivityListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -932,7 +1075,7 @@ class QueryActivityListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextCursor: 分页游标
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextCursor: str
@@ -956,13 +1099,6 @@ class QueryActivityListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryActivityLiveCodeListRequest(AbstractModel):
@@ -971,7 +1107,7 @@ class QueryActivityLiveCodeListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cursor: 用于分页查询的游标，字符串类型，由上一次调用返回，首次调用可不填
         :type Cursor: str
         :param Limit: 返回的最大记录数，整型，最大值100，默认值50，超过最大值时取最大值
@@ -989,7 +1125,7 @@ class QueryActivityLiveCodeListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -999,7 +1135,7 @@ class QueryActivityLiveCodeListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextCursor: 分页游标，再下次请求时填写以获取之后分页的记录，如果已经没有更多的数据则返回空
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextCursor: str
@@ -1023,13 +1159,6 @@ class QueryActivityLiveCodeListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryChannelCodeListRequest(AbstractModel):
@@ -1038,7 +1167,7 @@ class QueryChannelCodeListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cursor: 用于分页查询的游标，字符串类型，由上一次调用返回，首次调用可不填
         :type Cursor: str
         :param Limit: 返回的最大记录数，整型，最大值100，默认值50，超过最大值时取最大值
@@ -1056,7 +1185,7 @@ class QueryChannelCodeListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1066,7 +1195,7 @@ class QueryChannelCodeListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextCursor: 分页游标，再下次请求时填写以获取之后分页的记录，如果已经没有更多的数据则返回空
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextCursor: str
@@ -1090,13 +1219,6 @@ class QueryChannelCodeListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryChatArchivingListRequest(AbstractModel):
@@ -1105,7 +1227,7 @@ class QueryChatArchivingListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cursor: 用于分页查询的游标，字符串类型，由上一次调用返回，首次调用可不填
         :type Cursor: str
         :param Limit: 返回的最大记录数，整型，最大值100，默认值50，超过最大值时取最大值
@@ -1123,7 +1245,7 @@ class QueryChatArchivingListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1133,7 +1255,7 @@ class QueryChatArchivingListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextCursor: 分页游标，再下次请求时填写以获取之后分页的记录，如果已经没有更多的数据则返回空
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextCursor: str
@@ -1157,22 +1279,80 @@ class QueryChatArchivingListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
+
+
+class QueryClueInfoListRequest(AbstractModel):
+    """QueryClueInfoList请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Cursor: 用于分页查询的游标，字符串类型，由上一次调用返回，首次调用可不填
+        :type Cursor: str
+        :param Limit: 返回的最大记录数，整型，最大值100，默认值50，超过最大值时取最大值
+        :type Limit: int
+        """
+        self.Cursor = None
+        self.Limit = None
+
+
+    def _deserialize(self, params):
+        self.Cursor = params.get("Cursor")
+        self.Limit = params.get("Limit")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
+class QueryClueInfoListResponse(AbstractModel):
+    """QueryClueInfoList返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PageData: 线索信息列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PageData: list of ClueInfoDetail
+        :param NextCursor: 分页游标，下次调用带上该值，则从当前的位置继续往后拉，以实现增量拉取。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NextCursor: str
+        :param HasMore: 是否还有更多数据。0-否；1-是。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type HasMore: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.PageData = None
+        self.NextCursor = None
+        self.HasMore = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("PageData") is not None:
+            self.PageData = []
+            for item in params.get("PageData"):
+                obj = ClueInfoDetail()
+                obj._deserialize(item)
+                self.PageData.append(obj)
+        self.NextCursor = params.get("NextCursor")
+        self.HasMore = params.get("HasMore")
+        self.RequestId = params.get("RequestId")
+
+
 class QueryExternalContactDetailRequest(AbstractModel):
     """QueryExternalContactDetail请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExternalUserId: 外部联系人的userid，注意不是企业成员的帐号
         :type ExternalUserId: str
         :param Cursor: 用于分页查询的游标，字符串类型，由上一次调用返回，首次调用可不填。当客户在企业内的跟进人超过500人时需要使用cursor参数进行分页获取
@@ -1194,7 +1374,7 @@ class QueryExternalContactDetailRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1204,7 +1384,7 @@ class QueryExternalContactDetailResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextCursor: 分页游标，再下次请求时填写以获取之后分页的记录，如果已经没有更多的数据则返回空
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextCursor: str
@@ -1235,13 +1415,6 @@ class QueryExternalContactDetailResponse(AbstractModel):
                 obj._deserialize(item)
                 self.FollowUser.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryExternalContactListRequest(AbstractModel):
@@ -1250,7 +1423,7 @@ class QueryExternalContactListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cursor: 用于分页查询的游标，字符串类型，由上一次调用返回，首次调用可不填
         :type Cursor: str
         :param Limit: 返回的最大记录数，整型，最大值100，默认值50，超过最大值时取最大值
@@ -1268,7 +1441,7 @@ class QueryExternalContactListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1278,7 +1451,7 @@ class QueryExternalContactListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PageData: 外部联系人信息列表
 注意：此字段可能返回 null，表示取不到有效值。
         :type PageData: list of ExternalContactSimpleInfo
@@ -1302,22 +1475,114 @@ class QueryExternalContactListResponse(AbstractModel):
                 self.PageData.append(obj)
         self.NextCursor = params.get("NextCursor")
         self.RequestId = params.get("RequestId")
+
+
+class QueryExternalUserMappingInfoRequest(AbstractModel):
+    """QueryExternalUserMappingInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param CorpExternalUserIdList: 企业主体对应的外部联系人id列表，列表长度限制最大为50。
+        :type CorpExternalUserIdList: list of str
+        """
+        self.CorpExternalUserIdList = None
+
+
+    def _deserialize(self, params):
+        self.CorpExternalUserIdList = params.get("CorpExternalUserIdList")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
+class QueryExternalUserMappingInfoResponse(AbstractModel):
+    """QueryExternalUserMappingInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ExternalUserIdMapping: 外部联系人映射信息, 只返回映射成功的记录
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExternalUserIdMapping: list of ExternalUserMappingInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ExternalUserIdMapping = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("ExternalUserIdMapping") is not None:
+            self.ExternalUserIdMapping = []
+            for item in params.get("ExternalUserIdMapping"):
+                obj = ExternalUserMappingInfo()
+                obj._deserialize(item)
+                self.ExternalUserIdMapping.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class QueryLicenseInfoRequest(AbstractModel):
+    """QueryLicenseInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param License: license编号
+        :type License: str
+        """
+        self.License = None
+
+
+    def _deserialize(self, params):
+        self.License = params.get("License")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class QueryLicenseInfoResponse(AbstractModel):
+    """QueryLicenseInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param LicenseInfo: license响应信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LicenseInfo: :class:`tencentcloud.wav.v20210129.models.LicenseInfo`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.LicenseInfo = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("LicenseInfo") is not None:
+            self.LicenseInfo = LicenseInfo()
+            self.LicenseInfo._deserialize(params.get("LicenseInfo"))
+        self.RequestId = params.get("RequestId")
+
+
 class QueryMiniAppCodeListRequest(AbstractModel):
     """QueryMiniAppCodeList请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cursor: 用于分页查询的游标，字符串类型，由上一次调用返回，首次调用可不填
         :type Cursor: str
         :param Limit: 返回的最大记录数，整型，最大值100，默认值50，超过最大值时取最大值
@@ -1335,7 +1600,7 @@ class QueryMiniAppCodeListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1345,7 +1610,7 @@ class QueryMiniAppCodeListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NextCursor: 分页游标，再下次请求时填写以获取之后分页的记录，如果已经没有更多的数据则返回空
 注意：此字段可能返回 null，表示取不到有效值。
         :type NextCursor: str
@@ -1369,13 +1634,6 @@ class QueryMiniAppCodeListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class TagDetailInfo(AbstractModel):
@@ -1384,7 +1642,7 @@ class TagDetailInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TagName: 标签名称
         :type TagName: str
         :param BizTagId: 标签业务ID
@@ -1414,7 +1672,7 @@ class TagDetailInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1424,7 +1682,7 @@ class TagGroup(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GroupId: 企微标签组id
         :type GroupId: str
         :param BizGroupId: 标签组业务id
@@ -1463,7 +1721,7 @@ class TagGroup(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1473,7 +1731,7 @@ class TagInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TagName: 标签名称, 最大长度限制15个字符
         :type TagName: str
         :param Sort: 标签组排序,值越大,排序越靠前
@@ -1491,7 +1749,7 @@ class TagInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1501,7 +1759,7 @@ class WeComTagDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GroupName: 标签分组名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type GroupName: str
@@ -1546,5 +1804,5 @@ class WeComTagDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
